@@ -35,7 +35,7 @@ class ErrorInfo(Error):
 
     name = "use-pathlib-write-text-write-bytes"
     code = 103
-    categories = ["pathlib"]
+    categories = ("pathlib",)
 
 
 def check(node: WithStmt, errors: list[Error]) -> None:
